<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/core/RUnit.cpp" line="+272"/>
        <source>None</source>
        <translation>Niente</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Inch</source>
        <translation>Pollice</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Foot</source>
        <translation>Piede</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Mile</source>
        <translation>Miglio</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Millimeter</source>
        <translation>Millimetro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Centimeter</source>
        <translation>Centimetro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Meter</source>
        <translation>Metro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Kilometer</source>
        <translation>Chilometro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Microinch</source>
        <translation>Micropollice</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Mil</source>
        <translation>Millesimo di pollice</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Yard</source>
        <translation>Iarda</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Angstrom</source>
        <translation>Angstrom</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Nanometer</source>
        <translation>Nanometro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Micron</source>
        <translation>Micromillimetro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Decimeter</source>
        <translation>Decimetro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Decameter</source>
        <translation>Decametro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Hectometer</source>
        <translation>Ettometro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Gigameter</source>
        <translation>Gigametro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Astro</source>
        <translation>Astro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Lightyear</source>
        <translation>Anno luce</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Parsec</source>
        <translation>Parsec</translation>
    </message>
</context>
<context>
    <name>RColor</name>
    <message>
        <location filename="../src/core/RColor.cpp" line="+340"/>
        <source>By Layer</source>
        <translation>Da livello</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>By Block</source>
        <translation>Da Blocco</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Red</source>
        <translation>Rosso</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Yellow</source>
        <translation>Giallo</translation>
    </message>
    <message>
        <location line="-4"/>
        <source>Green</source>
        <translation>Verde</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Cyan</source>
        <translation>Ciano</translation>
    </message>
    <message>
        <location line="-1"/>
        <source>Blue</source>
        <translation>Blu</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Magenta</source>
        <translation>Magenta</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Orange</source>
        <translation>Arancione</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Red</source>
        <translation>Rosso scuro</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Green</source>
        <translation>Verde scuro</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Blue</source>
        <translation>Blu scuro</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Cyan</source>
        <translation>Scuro ciano</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Magenta</source>
        <translation>Magenta scuro</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Yellow</source>
        <translation>Giallo scuro</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Black</source>
        <translation>Nero</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>White</source>
        <translation>Bianco</translation>
    </message>
    <message>
        <location line="-2"/>
        <source>Gray</source>
        <translation>Grigio</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Light Gray</source>
        <translation>Grigio chiaro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Others...</source>
        <translation>Altri...</translation>
    </message>
</context>
<context>
    <name>RDocumentVariables</name>
    <message>
        <location filename="../src/core/RDocumentVariables.cpp" line="+48"/>
        <source>Current Layer ID</source>
        <translation>ID del livello corrente</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Drawing Unit</source>
        <translation>Unità di disegno</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Linetype Scale</source>
        <translation>Scala del tipo di linea</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dimension Font</source>
        <translation>Carattere per quota</translation>
    </message>
</context>
<context>
    <name>REntity</name>
    <message>
        <location filename="../src/core/REntity.cpp" line="+95"/>
        <source>Block</source>
        <translation>Blocco</translation>
    </message>
    <message>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="+100"/>
        <source>Referenced Block</source>
        <translation>Blocco referenziato</translation>
    </message>
    <message>
        <location filename="../src/core/RBlock.cpp" line="+76"/>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="+2"/>
        <location line="+3"/>
        <location filename="../src/core/RLayout.cpp" line="+83"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/core/RTextBasedEntity.cpp" line="+75"/>
        <location filename="../src/core/RViewportEntity.cpp" line="+80"/>
        <location line="+8"/>
        <location line="+2"/>
        <source>X</source>
        <translation>X</translation>
    </message>
    <message>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-3"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-10"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Position</source>
        <translation>Posizione</translation>
    </message>
    <message>
        <location filename="../src/core/RBlock.cpp" line="-1"/>
        <source>Pixel Unit</source>
        <translation>Pixel unità</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Origin</source>
        <translation>Origine</translation>
    </message>
    <message>
        <location line="-1"/>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-1"/>
        <location line="+3"/>
        <location filename="../src/core/RLayout.cpp" line="-11"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/core/RTextBasedEntity.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-1"/>
        <location line="+8"/>
        <location line="+2"/>
        <source>Y</source>
        <translation>Y</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/core/RLayout.cpp" line="-11"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/core/RTextBasedEntity.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-9"/>
        <location line="+10"/>
        <source>Z</source>
        <translation>Z</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Layout</source>
        <translation>Layout</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Owned by Reference</source>
        <translation>Di proprietà di Riferimento</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>External reference</source>
        <translation>Riferimento esterno</translation>
    </message>
    <message>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-6"/>
        <source>External Reference</source>
        <translation>Riferimento esterno</translation>
    </message>
    <message>
        <location line="+4"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-7"/>
        <source>Scale</source>
        <translation>Scala</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Angle</source>
        <translation>Angolo</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Columns</source>
        <translation>Colonne</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Rows</source>
        <translation>Righe</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Column Spacing</source>
        <translation>Interasse colonne</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Row Spacing</source>
        <translation>Interasse righe</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Attributes</source>
        <translation>Attributi</translation>
    </message>
    <message>
        <location filename="../src/core/REntity.cpp" line="-1"/>
        <location filename="../src/core/RObject.cpp" line="+70"/>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Layer</source>
        <translation>Livello</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayer.cpp" line="+104"/>
        <source>Linetype</source>
        <translation>Tipo di linea</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Linetype Scale</source>
        <translation>Scala del tipo</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayer.cpp" line="+1"/>
        <source>Lineweight</source>
        <translation>Spessore di linea</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayer.cpp" line="-2"/>
        <source>Color</source>
        <translation>Colore</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Displayed Color</source>
        <translation>Colore visualizzato</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Draw Order</source>
        <translation>Ordine di disegno</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Parent Id</source>
        <translation>Parent Id</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Boundary</source>
        <translation>Limite</translation>
    </message>
    <message>
        <location line="-3"/>
        <location filename="../src/core/RLayout.cpp" line="+3"/>
        <source>Left</source>
        <translation>Sinistra</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Bottom</source>
        <translation>Sotto</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Right</source>
        <translation>Destra</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Top</source>
        <translation>Sopra</translation>
    </message>
    <message>
        <location filename="../src/core/RObject.cpp" line="-1"/>
        <location filename="../src/core/RPropertyTypeId.cpp" line="+162"/>
        <source>Custom</source>
        <translation>Personalizzato</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Handle</source>
        <translation>Manico</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Protected</source>
        <translation>Protetta</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Selected</source>
        <translation>Selezionato</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Object Invisible</source>
        <translation>Oggetto invisibile</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Working Set</source>
        <translation>Set di lavoro</translation>
    </message>
    <message>
        <location filename="../src/core/REntity.cpp" line="+2"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-2"/>
        <source>Width</source>
        <translation>Larghezza</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+1"/>
        <source>Size</source>
        <translation>Dimensioni</translation>
    </message>
    <message>
        <location line="+0"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="+1"/>
        <source>Height</source>
        <translation>Altezza</translation>
    </message>
    <message>
        <location filename="../src/core/RTextBasedEntity.cpp" line="-3"/>
        <source>Simple</source>
        <translation>Semplice</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Text Position</source>
        <translation>Posizione del testo</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text</source>
        <translation>Testo</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plain Text</source>
        <translation>Testo normale</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Font Name</source>
        <translation>Nome carattere</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text Height</source>
        <translation>Altezza testo</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text Width</source>
        <translation>Larghezza del testo</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text Angle</source>
        <translation>Angolo testo</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>X Scale</source>
        <translation>Scala X</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Bold</source>
        <translation>Grassetto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Italic</source>
        <translation>Italico</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Line Spacing</source>
        <translation>Interasse linee</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <source>Alignment</source>
        <translation>Allineamento</translation>
    </message>
    <message>
        <location line="-1"/>
        <source>Horizontal</source>
        <translation>Orizzontale</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Vertical</source>
        <translation>Verticale</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Backward</source>
        <translation>A rovescio</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Upside Down</source>
        <translation>Sottosopra</translation>
    </message>
    <message>
        <location filename="../src/core/RViewportEntity.cpp" line="+2"/>
        <source>Rotation</source>
        <translation>Rotazione</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>On</source>
        <translation>Acceso</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <source>View Center</source>
        <translation>Visualizza centro</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>View Target</source>
        <translation>Visualizza obiettivo</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Overall</source>
        <translation>Overall</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Frozen Layers</source>
        <translation>Livelli congelati</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Layer ID</source>
        <translation>ID livello</translation>
    </message>
    <message>
        <location filename="../src/core/RBlock.cpp" line="-8"/>
        <location filename="../src/core/RLayer.cpp" line="-8"/>
        <location filename="../src/core/RLayerState.cpp" line="+46"/>
        <location filename="../src/core/RLayout.cpp" line="-24"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Hidden</source>
        <translation>Nascosta</translation>
    </message>
    <message>
        <location filename="../src/core/RLayer.cpp" line="+1"/>
        <source>Off</source>
        <translation>Inattivo</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Frozen</source>
        <translation>Nascosto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Locked</source>
        <translation>Bloccato</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Collapsed</source>
        <translation>Piegato</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plottable</source>
        <translation>Tracciabile</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Snappable</source>
        <translation>Scattante</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Off is Freeze</source>
        <translation>Inattivo è congelare</translation>
    </message>
    <message>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Tab Order</source>
        <translation>Ordine di tabulazione</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Min Limits</source>
        <translation>Min limiti</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Max Limits</source>
        <translation>Max limiti</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Insertion Base</source>
        <translation>Inserimento base</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Min Extents</source>
        <translation>Min estensioni</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Max Extents</source>
        <translation>Max estensioni</translation>
    </message>
    <message>
        <location filename="../src/core/RBlockReferenceData.cpp" line="+920"/>
        <source>Circular (recursive) block referencing detected:</source>
        <translation>È stato rilevato un riferimento circolare (ricorsivo) blocco:</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Block name:</source>
        <translation>Nome del blocco:</translation>
    </message>
    <message>
        <location filename="../src/core/RDimStyle.cpp" line="+71"/>
        <source>Style</source>
        <translation>Stile</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Linear measurement factor</source>
        <translation>Fattore di misura lineare</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text height</source>
        <translation>Altezza del testo</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dimension line gap</source>
        <translation>Spazio tra le linee di dimensione</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Arrow size</source>
        <translation>Dimensione della freccia</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dimension line increment</source>
        <translation>Incremento della linea di dimensione</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Extension line extension</source>
        <translation>Estensione della linea di estensione</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Extension line offset</source>
        <translation>Offset della linea di estensione</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text position vertical</source>
        <translation>Posizione del testo verticale</translation>
    </message>
    <message>
        <location line="-8"/>
        <source>Overall scale</source>
        <translation>Scala globali</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Text horizontal</source>
        <translation>Testo orizzontale</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Tick size</source>
        <translation>Dimensione del segno di spunta</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Linear format</source>
        <translation>Formato lineare</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Decimal places</source>
        <translation>Posizioni decimali</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Decimal separator</source>
        <translation>Separatore decimale</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Zero suppression</source>
        <translation>Soppressione zero</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Angular format</source>
        <translation>Formato angolare</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Angular decimal places</source>
        <translation>Decimali angolari</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Angular zero suppression</source>
        <translation>Soppressione dello zero angolare</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Architectur tick</source>
        <translation>Spunta l&apos;architettura</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text color</source>
        <translation>Colore del testo</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Arrow block</source>
        <translation>Blocco della freccia</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Arrow block 1</source>
        <translation>Blocco freccia 1</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Arrow block 2</source>
        <translation>Blocco freccia 2</translation>
    </message>
</context>
<context>
    <name>RGuiAction</name>
    <message>
        <location filename="../src/core/RGuiAction.cpp" line="+203"/>
        <source>Requires selection</source>
        <translation>Richiede selezione</translation>
    </message>
</context>
<context>
    <name>RLinetype</name>
    <message>
        <location filename="../src/core/RLinetype.cpp" line="+51"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Description</source>
        <translation>Descrizione</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Metric</source>
        <translation>Metrico</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Pattern</source>
        <translation>Modello</translation>
    </message>
</context>
<context>
    <name>RLinetypePattern</name>
    <message>
        <location filename="../src/core/RLinetypePattern.cpp" line="+912"/>
        <source>By Layer</source>
        <translation>Da livello</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>By Block</source>
        <translation>Da Blocco</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Continuous</source>
        <translation>Continua</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Border</source>
        <translation>Bordo</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Center</source>
        <translation>Centro</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dash dot</source>
        <translation>Tratto punto</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dashed</source>
        <translation>Tratteggiata</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Divide</source>
        <translation>Dividi</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dot</source>
        <translation>Punto</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Hidden</source>
        <translation>Nascosta</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Phantom</source>
        <translation>Fantasma</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>ISO dash</source>
        <translation>Tratto ISO</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash space</source>
        <translation>Tratto ISO spazio</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash dot</source>
        <translation>Tratto lungo ISO punti</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash double-dot</source>
        <translation>Tratto lungo ISO due punti</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash triple-dot</source>
        <translation>Tratto lungo ISO tre punti</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dot</source>
        <translation>Punto ISO</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash short-dash</source>
        <translation>Tratto lungo ISO tratto corto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash double-short-dash</source>
        <translation>Tratto lungo ISO due tratti corti</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash dot</source>
        <translation>Tratto ISO punto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO double-dash dot</source>
        <translation>Due tratti ISO punto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash double-dot</source>
        <translation>Tratto ISO due punti</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO double-dash double-dot</source>
        <translation>Linea doppia ISO punto doppio</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash triple-dot</source>
        <translation>Tratto ISO tre punti</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO double-dash triple-dot</source>
        <translation>Due tratti ISO tre punti</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Hot Water Supply</source>
        <translation>Acqua calda</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Hot Water</source>
        <translation>Acqua calda</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Gas Line</source>
        <translation>Gasdotto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Batting</source>
        <translation>Isolamento</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Zig Zag</source>
        <translation>Zig zag</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Tracks</source>
        <translation>Binario</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Fenceline 1</source>
        <translation>Limite 1</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Fenceline 2</source>
        <translation>Limite 2</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Point 1</source>
        <translation>Punto 1</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Point 2</source>
        <translation>Punto 2</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plant</source>
        <translation>Impianto</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Water</source>
        <translation>Acqua</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Drainage</source>
        <translation>Drenaggio</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Drainage Reversed</source>
        <translation>Drenaggio inverti</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Communication</source>
        <translation>Comunicazione</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Electric</source>
        <translation>Elettrico</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Low Voltage</source>
        <translation>Bassa tensione</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>High Voltage</source>
        <translation>Alta tensione</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Overhead Power</source>
        <translation>Potenza aerea</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Foul</source>
        <translation>Non pulito</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Foul Rising</source>
        <translation>Risalita non pulita</translation>
    </message>
</context>
<context>
    <name>RLineweight</name>
    <message>
        <location filename="../src/core/RLineweight.cpp" line="+37"/>
        <source>By Layer</source>
        <translation>Da livello</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>By Block</source>
        <translation>Da Blocco</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Default</source>
        <translation>Predefinito</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.00mm</source>
        <translation>0.00mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.05mm</source>
        <translation>0.05mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.09mm</source>
        <translation>0.09mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.13mm (ISO)</source>
        <translation>0.13mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.15mm</source>
        <translation>0.15mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.18mm (ISO)</source>
        <translation>0.18mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.20mm</source>
        <translation>0.20mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.25mm (ISO)</source>
        <translation>0.25mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.30mm</source>
        <translation>0.30mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.35mm (ISO)</source>
        <translation>0.35mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.40mm</source>
        <translation>0.40mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.50mm (ISO)</source>
        <translation>0.50mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.53mm</source>
        <translation>0.53mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.60mm</source>
        <translation>0.60mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.70mm (ISO)</source>
        <translation>0.70mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.80mm</source>
        <translation>0.80mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.90mm</source>
        <translation>0.90mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.00mm (ISO)</source>
        <translation>1.00mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.06mm</source>
        <translation>1.06mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.20mm</source>
        <translation>1.20mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.40mm (ISO)</source>
        <translation>1.40mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.58mm</source>
        <translation>1.58mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>2.00mm (ISO)</source>
        <translation>2.00mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>2.11mm</source>
        <translation>2.11mm</translation>
    </message>
</context>
</TS>
